@@ -1,13 +1,12 @@
 library(Rpolyhedra)
 library(stringr)
-library(futile.logger)
+library(lgr)
 library(rgl)
 library(geometry)
 library(testthat)
 
 # Change threshold to ERROR. Comment out/change if verbosity required for development
-futile.logger::flog.threshold(futile.logger::ERROR)
-
+lgr::basic_config(threshold = "error")
 #' getDataDirMockedTest mocked function for a temp dest folder for testing proposes
 
 
